#import "MSConvertCoordinatesViewController.h"

@interface MSConvertCoordinatesViewController ()
@property (nonatomic, strong) UIView *markerView;
@property (nonatomic, strong) MRPointAnnotation *userAnnotation;
@end

@implementation MSConvertCoordinatesViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.mapView.mapKey = [MREditorKey keyForMap:[MSExampleHost mapID] app:[MSExampleHost appID]];
    }
    return self;
}

#pragma mark - UIViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    self.markerView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, 10, 10)];
    self.markerView.backgroundColor = [UIColor redColor];
    [self.mapView addSubview:self.markerView];
    
    self.userAnnotation = [[MRPointAnnotation alloc] init];
    self.userAnnotation.point = CGPointMake(0, 0);
    [self.mapView addAnnotation:self.userAnnotation];
    
    UIBarButtonItem *button1 = [[UIBarButtonItem alloc] initWithTitle:@"Position Markers" style:UIBarButtonItemStylePlain target:self action:@selector(layoutMarkers)];
    self.navigationItem.rightBarButtonItems = @[button1];
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Convert Coordinates";
}

+ (NSString *)exampleInfo {
    return @"Example of how to convert to and from the map coordinate system.\n\n"
    @"• Button to reposition red and blue markers.\n"
    @"• Blue annotation is moved to the center of the map view.\n"
    @"• Red view is moved above the 'KFC' placemark.\n";
}

#pragma mark - Action

- (void)layoutMarkers {
    MRPlacemark *placemark = nil;
    for (MRPlacemark *i in self.mapView.placemarks) {
        if ([i.title isEqual:@"KFC"]) {
            placemark = i;
        }
    }
    self.markerView.center = [self.mapView convertMapPoint:placemark.point toPointToView:self.mapView];
    [self.mapView bringSubviewToFront:self.markerView];
    
    self.userAnnotation.point = [self.mapView convertPoint:CGPointMake(CGRectGetMidX(self.mapView.bounds), CGRectGetMidY(self.mapView.bounds)) toMapPointFromView:self.mapView];
}

#pragma mark - MRMapViewDelegate

- (MRAnnotationView *)mapView:(MRMapView *)mapView viewForAnnotation:(id<MRAnnotation>)annotation {
    MRAnnotationView *superAnnotationView = [super mapView:mapView viewForAnnotation:annotation];
    if (annotation == self.userAnnotation) {
        MRAnnotationView *annotationView = [self.mapView dequeueReusableAnnotationViewWithIdentifier:@"a"];
        if (!annotationView) {
            annotationView = [[MRAnnotationView alloc] initWithAnnotation:self.userAnnotation reuseIdentifier:@"a"];
            annotationView.frame = CGRectMake(0, 0, 10, 10);
            annotationView.backgroundColor = [UIColor blueColor];
        }
        return annotationView;
    }
    return superAnnotationView;
}

@end
