#import "MSCustomAnnotationViewController.h"

@interface MSCustomAnnotationViewController ()
@property (nonatomic) BOOL blueRestaurantIcons;
@end

@implementation MSCustomAnnotationViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.mapView.mapKey = [MREditorKey keyForMap:[MSExampleHost mapID] app:[MSExampleHost appID]];
        self.mapView.showsUserLocation = YES;
    }
    return self;
}

#pragma mark - UIViewController

- (void)viewDidLoad {
    [super viewDidLoad];

    UIBarButtonItem *button1 = [[UIBarButtonItem alloc] initWithTitle:@"Toggle Color" style:UIBarButtonItemStylePlain target:self action:@selector(toggleColorAction)];
    self.navigationItem.rightBarButtonItems = @[button1];
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Custom Placemark Annotations";
}

+ (NSString *)exampleInfo {
    return @"Example of how to customize placemark annotations.\n\n"
    @"• Restrooms have a title of `W/C`.\n"
    @"• Restaurants have a custom icon, font, and text color.\n"
    @"• Button to toggle restaurant color between red and blue.\n";
}

#pragma mark - MRMapViewDelegate

- (MRAnnotationView *)mapView:(MRMapView *)mapView viewForAnnotation:(id<MRAnnotation>)annotation {
    MRAnnotationView *superAnnotationView = [super mapView:mapView viewForAnnotation:annotation];
    if ([annotation isKindOfClass:[MRPlacemark class]]) {
        MRPlacemark *placemark = (MRPlacemark *)annotation;
        if ([placemark.type hasPrefix:@"restroom"]) {
            placemark.name = @"W/C";
        } else if ([placemark.type isEqualToString:@"restaurant"]) {
            MRPlacemarkAnnotationView *defaultView = (MRPlacemarkAnnotationView *)[mapView defaultViewForAnnotation:annotation];
            if (self.blueRestaurantIcons) {
                defaultView.iconBackgroundColor = [UIColor blueColor];
            } else {
                defaultView.iconBackgroundColor = [UIColor redColor];
            }
            defaultView.textColor = [UIColor grayColor];
            defaultView.font = [UIFont fontWithName:@"Papyrus" size:14];
            return defaultView;
        }
    }
    return superAnnotationView;
}

#pragma mark - Action

- (void)toggleColorAction {
    self.blueRestaurantIcons = !self.blueRestaurantIcons;
    for (MRPlacemark *i in self.mapView.placemarks) {
        if ([i.type isEqualToString:@"restaurant"]) {
            MRPlacemarkAnnotationView *view = (id)[self.mapView viewForAnnotation:i];
            if (self.blueRestaurantIcons) {
                view.iconBackgroundColor = [UIColor blueColor];
            } else {
                view.iconBackgroundColor = [UIColor redColor];
            }
        }
    }
}

@end
