#import "MSCustomUserAnnotationViewController.h"

@interface MSUserAnnotationView : MRAnnotationView
@property (nonatomic, strong) CAShapeLayer *shapeLayer;
@end

@implementation MSUserAnnotationView
- (id)initWithAnnotation:(id<MRAnnotation>)annotation reuseIdentifier:(NSString *)reuseIdentifier {
    if ((self = [super initWithAnnotation:annotation reuseIdentifier:reuseIdentifier])) {
        self.shapeLayer = [CAShapeLayer layer];
        self.shapeLayer.path = [UIBezierPath bezierPathWithOvalInRect:CGRectMake(0, 0, 20, 20)].CGPath;
        self.shapeLayer.lineWidth = 3;
        self.shapeLayer.fillColor = [UIColor orangeColor].CGColor;
        self.shapeLayer.strokeColor = [UIColor whiteColor].CGColor;
        self.shapeLayer.shadowOpacity = 0.5;
        self.shapeLayer.shadowOffset = CGSizeMake(0, 1);
        [self.layer addSublayer:self.shapeLayer];
        
        self.frame = CGRectMake(0, 0, 20, 20);
    }
    return self;
}
@end

@implementation MSCustomUserAnnotationViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.mapView.mapKey = [MREditorKey keyForMap:[MSExampleHost mapID] app:[MSExampleHost appID]];
        self.mapView.showsUserLocation = YES;
    }
    return self;
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Custom User Annotation";
}

+ (NSString *)exampleInfo {
    return @"Example of how to customize annotations by returning a MRAnnotationView subclass.\n\n"
    @"• Custom orange user location annotation.\n";
}

#pragma mark - MRMapViewDelegate

- (MRAnnotationView *)mapView:(MRMapView *)mapView viewForAnnotation:(id<MRAnnotation>)annotation {
    MRAnnotationView *superAnnotationView = [super mapView:mapView viewForAnnotation:annotation];
    if ([annotation isKindOfClass:[MRUserLocation class]]) {
        MSUserAnnotationView *view = (MSUserAnnotationView *)[mapView dequeueReusableAnnotationViewWithIdentifier:@"MSUserAnnotationView"];
        if (!view) {
            view = [[MSUserAnnotationView alloc] initWithAnnotation:annotation reuseIdentifier:@"MSUserAnnotationView"];
        }
        return view;
    }
    return superAnnotationView;
}

@end
