#import "MSOverlayViewController.h"

@interface MSOverlayViewController ()
@property (nonatomic) BOOL blueOverlayState;

@property (nonatomic, strong) MRPathOverlay *circleOverlay;
@property (nonatomic, strong) MRPathOverlay *pathOverlay;
@property (nonatomic) NSMutableDictionary *placemarkOverlays;

@end

@implementation MSOverlayViewController

// default colors
UIColor *overlayBlueStrokeOpaqueColor = nil;
UIColor *overlayBlueStrokeColor = nil;
UIColor *overlayBlueFillColor = nil;
UIColor *overlayRedStrokeOpaqueColor = nil;
UIColor *overlayRedStrokeColor = nil;
UIColor *overlayRedFillColor = nil;


- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.mapView.mapKey = [MREditorKey keyForMap:[MSExampleHost mapID] app:[MSExampleHost appID]];
        self.mapView.showsUserLocation = YES;
    }
    return self;
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Custom Overlays";
}

+ (NSString *)exampleInfo {
    return @"Example of how to add custom overlays.\n\n"
    @"• Button to toggle the appearance of overlays.\n"
    @"• Button to toggle the existence of overlays.\n";
}

#pragma mark - UIViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    UIBarButtonItem *button1 = [[UIBarButtonItem alloc] initWithTitle:@"Toggle Overlay" style:UIBarButtonItemStylePlain target:self action:@selector(toggleOverlay)];
    UIBarButtonItem *button2 = [[UIBarButtonItem alloc] initWithTitle:@"Toggle Color" style:UIBarButtonItemStylePlain target:self action:@selector(toggleColor)];
    self.navigationItem.rightBarButtonItems = @[button1, button2];
    
    self.placemarkOverlays = [[NSMutableDictionary alloc] init];
    self.circleOverlay = nil;
    self.pathOverlay = nil;
    
    // default colors for this sample
    overlayBlueStrokeOpaqueColor = [[UIColor blueColor] colorWithAlphaComponent:1.0];
    overlayBlueStrokeColor = [[UIColor blueColor] colorWithAlphaComponent:0.4];
    overlayBlueFillColor = [[UIColor blueColor] colorWithAlphaComponent:0.2];
    overlayRedStrokeOpaqueColor = [[UIColor redColor] colorWithAlphaComponent:1.0];
    overlayRedStrokeColor = [[UIColor redColor] colorWithAlphaComponent:0.4];
    overlayRedFillColor = [[UIColor redColor] colorWithAlphaComponent:0.2];
    
    [self toggleOverlay];
}

#pragma mark - MRMapViewDelegate

- (MRAnnotationView *)mapView:(MRMapView *)mapView viewForAnnotation:(id<MRAnnotation>)annotation {
    MRAnnotationView *superAnnotationView = [super mapView:mapView viewForAnnotation:annotation];
    if ([annotation isKindOfClass:[MRPlacemark class]]) {
        MRPlacemark *placemark = (MRPlacemark *)annotation;
        if (placemark.area != NULL) {
            
            // A new MRPathOverlay should only be created if it does not already exist
            if(self.placemarkOverlays[placemark.key] == nil) {
                MRPathOverlay* overlay = [[MRPathOverlay alloc] initWithPlacemark:placemark];
                overlay.userInteractionEnabled = TRUE;
                [mapView addOverlay:overlay];
                self.placemarkOverlays[placemark.key] = overlay;
                [self mapView:self.mapView rendererForOverlay:overlay];
            }
        }
    }
    return superAnnotationView;
}

- (MRPathRenderer *)mapView:(MRMapView *)mapView rendererForOverlay:(MRPathOverlay *)overlay {
    MRPathRenderer *renderer = nil;
    renderer = [mapView rendererForOverlay:overlay];
    if(renderer != nil) {
        // override some renderer values for this sample
        [self initRenderer:renderer overlay:overlay];
    }
    return renderer;
}

- (void)mapView:(MRMapView *)mapView didTapOverlay:(MRPathOverlay *)overlay {
    [super mapView:mapView didTapOverlay:overlay];
    MRPathRenderer* renderer = [self mapView:self.mapView rendererForOverlay:overlay];
    if(renderer) {
        [self toggleStrokeColor:renderer];
        [self toggleFillColor:renderer];
    }
}


#pragma mark - Internal

- (void)initRenderer:(MRPathRenderer *)renderer overlay:(MRPathOverlay *)overlay {
    renderer.lineCap = kCGLineCapButt;
    renderer.lineJoin = kCGLineJoinBevel;
    
    if(overlay == self.circleOverlay) {
        renderer.lineWidth = 5;
        if(!CGColorEqualToColor(renderer.strokeColor.CGColor, overlayBlueStrokeOpaqueColor.CGColor) &&
           !CGColorEqualToColor(renderer.strokeColor.CGColor, overlayRedStrokeOpaqueColor.CGColor)) {
            renderer.strokeColor = self.blueOverlayState ? overlayBlueStrokeOpaqueColor : overlayRedStrokeOpaqueColor;
            renderer.fillColor = self.blueOverlayState ? overlayBlueFillColor : overlayRedFillColor;
        }
        
    } else if(overlay == self.pathOverlay) {
        renderer.lineWidth = 4;
        if(!CGColorEqualToColor(renderer.strokeColor.CGColor, overlayBlueStrokeOpaqueColor.CGColor) &&
           !CGColorEqualToColor(renderer.strokeColor.CGColor, overlayRedStrokeOpaqueColor.CGColor)) {
            renderer.strokeColor = self.blueOverlayState ? overlayBlueStrokeOpaqueColor : overlayRedStrokeOpaqueColor;
            renderer.fillColor = [UIColor clearColor];
        }
        
    } else {
        renderer.lineWidth = 3;
        if(!CGColorEqualToColor(renderer.strokeColor.CGColor, overlayBlueStrokeColor.CGColor) &&
           !CGColorEqualToColor(renderer.strokeColor.CGColor, overlayRedStrokeColor.CGColor)) {
            renderer.strokeColor = self.blueOverlayState ? overlayBlueStrokeColor : overlayRedStrokeColor;
            renderer.fillColor = self.blueOverlayState ? overlayBlueFillColor : overlayRedFillColor;
        }
    }
}

- (void)toggleStrokeColor:(MRPathRenderer*) renderer {
    if(CGColorEqualToColor(renderer.strokeColor.CGColor, overlayBlueStrokeColor.CGColor)) {
        renderer.strokeColor = overlayRedStrokeColor;
    } else if(CGColorEqualToColor(renderer.strokeColor.CGColor, overlayRedStrokeColor.CGColor)) {
        renderer.strokeColor = overlayBlueStrokeColor;
    } else if(CGColorEqualToColor(renderer.strokeColor.CGColor, overlayBlueStrokeOpaqueColor.CGColor)) {
        renderer.strokeColor = overlayRedStrokeOpaqueColor;
    } else {
        renderer.strokeColor = overlayBlueStrokeOpaqueColor;
    }
}

- (void)toggleFillColor:(MRPathRenderer*) renderer {
    if(CGColorEqualToColor(renderer.fillColor.CGColor, [UIColor clearColor].CGColor)) {
        renderer.fillColor = [UIColor clearColor];
    } else if(CGColorEqualToColor(renderer.fillColor.CGColor, overlayBlueFillColor.CGColor)) {
        renderer.fillColor = overlayRedFillColor;
    } else {
        renderer.fillColor = overlayBlueFillColor;
    }
}

- (void)AddPathOverlay {
    NSArray *points = [NSArray arrayWithObjects:
                       [NSValue valueWithCGPoint:CGPointMake(212, 298)],
                       [NSValue valueWithCGPoint:CGPointMake(370, 550)],
                       [NSValue valueWithCGPoint:CGPointMake(910, 240)],
                       [NSValue valueWithCGPoint:CGPointMake(1058, 270)],
                       nil];
    
    self.pathOverlay = [[MRPathOverlay alloc] initWithPolylineOfPoints:points];
    self.pathOverlay.userInteractionEnabled = TRUE;
    [self.mapView addOverlay:self.pathOverlay];
    [self mapView:self.mapView rendererForOverlay:self.pathOverlay];
}

- (void)AddCircleOverlay {
    self.circleOverlay = [[MRPathOverlay alloc] initWithCircleOfCenter:CGPointMake(200, 200) radius:50];
    self.circleOverlay.userInteractionEnabled = TRUE;
    [self.mapView addOverlay:self.circleOverlay];
    [self mapView:self.mapView rendererForOverlay:self.circleOverlay];
}

- (void)toggleOverlay {
    if (self.circleOverlay == nil) {
        [self AddCircleOverlay];
    } else {
        [self.mapView removeOverlay:self.circleOverlay];
        self.circleOverlay = nil;
    }
    
    if(self.pathOverlay == nil) {
        [self AddPathOverlay];
    } else {
        [self.mapView removeOverlay:self.pathOverlay];
        self.pathOverlay = nil;
    }
}

- (void)toggleColor {
    self.blueOverlayState = !self.blueOverlayState;
    
    NSArray* overlays = [self.mapView overlays];
    for (MRPathOverlay* overlay in overlays) {
        MRPathRenderer* renderer = [self mapView:self.mapView rendererForOverlay:overlay];
        if(renderer) {
            [self toggleStrokeColor:renderer];
            [self toggleFillColor:renderer];
        }
    }
}

@end


