//
//  MSAddAnnotationViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/19/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSAddAnnotationViewController: MRMapViewController, MSExampleViewController {
    private lazy var userAnnotation: MRPointAnnotation = {
        let userAnnotation = MRPointAnnotation()
        userAnnotation.point = CGPoint(x: 872, y: 420)
        userAnnotation.title = "Hello There"
        return userAnnotation
    }()

    private lazy var userAnnotation2: MRPointAnnotation = {
        let userAnnotation2 = MRPointAnnotation()
        userAnnotation2.point = CGPoint(x: 150, y: 100)
        userAnnotation2.title = "Hello Again"
        return userAnnotation2
    }()
    
    convenience init() {
        self.init(nibName:nil, bundle:nil)
        mapView.mapKey = MREditorKey(forMap: MSExampleHost.mapID(), app: MSExampleHost.appID())
    }

    override func viewDidLoad() {
        super.viewDidLoad()
        mapView.addAnnotation(userAnnotation)
        mapView.addAnnotation(userAnnotation2)

        let button0 = UIBarButtonItem(title: "Toggle", style: .plain, target: self, action: #selector(toggleAnnotation))
        navigationItem.rightBarButtonItems = [button0]
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Add Annotation"
    }

    static func exampleDetail() -> String {
        return """
        Example of how to add custom annotations.
        
        
        • Custom annotation with a smiley image and `Hello There` in the sheet.
        • Button to add/remove a second smiley annotation.
        """
    }

    // MARK: - MRMapViewDelegate

    override func mapView(_ mapView: MRMapView, viewFor annotation: MRAnnotation?) -> MRAnnotationView? {
        // Use the super's annotation view if we don't want to update anything
        let superAnnotationView = super.mapView(mapView, viewFor: annotation)

        if let thisAnnotation = annotation as? MRPointAnnotation, (thisAnnotation == userAnnotation || thisAnnotation == userAnnotation2) {
            if let annotationView = mapView.dequeueReusableAnnotationView(withIdentifier: "a") {
                return annotationView
            }
            let smileyView = UIImageView(image: #imageLiteral(resourceName: "Smiley"))
            smileyView.isUserInteractionEnabled = true
            let annotationView = MRAnnotationView.init(annotation: userAnnotation, reuseIdentifier: "a")
            annotationView.frame = smileyView.bounds
            annotationView.addSubview(smileyView)
            return annotationView
        }
        return superAnnotationView
    }

    // MARK: - Action

    @objc private func toggleAnnotation() {
        if mapView.annotations.contains(where: { $0 === userAnnotation2 }) {
           mapView.removeAnnotation(userAnnotation2)
        } else {
            mapView.addAnnotation(userAnnotation2)
        }
    }
}
