//
//  MSCustomAnnotationViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/19/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSCustomAnnotationViewController: MRMapViewController, MSExampleViewController {
    private var blueRestaurantIcons = false

    convenience init() {
        self.init(nibName:nil, bundle:nil)
        mapView.mapKey = MREditorKey(forMap: MSExampleHost.mapID(), app: MSExampleHost.appID())
        mapView.showsUserLocation = true
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()

        let button0 = UIBarButtonItem(title: "Toggle Color", style: .plain, target: self, action: #selector(toggleColorAction))
        navigationItem.rightBarButtonItems = [button0]
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Custom Placemark Annotations"
    }

    static func exampleDetail() -> String {
        return """
        Example of how to customize placemark annotations.
        
        • Restrooms have a title of `W/C`.
        • Restaurants have a custom icon, font, and text color.
        • Button to toggle restaurant color between red and blue.
        """
    }

    // MARK: - MRMapViewDelegate

    override func mapView(_ mapView: MRMapView, viewFor annotation: MRAnnotation?) -> MRAnnotationView? {
        // Return the super's version of the annotation view if we don't make our own
        let superAnnotationView = super.mapView(mapView, viewFor: annotation)

        if let placemark = annotation as? MRPlacemark, let type = placemark.type {
            if type.hasPrefix("restroom") {
                placemark.name = "W/C"
            } else if type == "restaurant" {
                guard let defaultView = mapView.defaultView(for: placemark) as? MRPlacemarkAnnotationView else {
                    return superAnnotationView
                }
                if blueRestaurantIcons {
                    defaultView.iconBackgroundColor = UIColor.blue
                } else {
                    defaultView.iconBackgroundColor = UIColor.red
                }
                defaultView.textColor = UIColor.gray
                defaultView.font = UIFont(name: "Papyrus", size: 14)
                return defaultView
            }
        }
        return superAnnotationView
    }

    // MARK: - Action

    @objc private func toggleColorAction() {
        blueRestaurantIcons = !blueRestaurantIcons
        for case let placemark as MRPlacemark in mapView.placemarks {
            if let type = placemark.type, type == "restaurant" {
                guard let view = mapView.view(for: placemark) as? MRPlacemarkAnnotationView else {
                    continue
                }
                if blueRestaurantIcons {
                    view.iconBackgroundColor = UIColor.blue
                } else {
                    view.iconBackgroundColor = UIColor.red
                }
            }
        }
    }
}
