//
//  MSDelegateViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/18/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSDelegateViewController: MRMapViewController, MSExampleViewController {
    convenience init() {
        self.init(nibName:nil, bundle:nil)
        mapView.mapKey = MREditorKey(forMap: MSExampleHost.mapID(), app: MSExampleHost.appID())
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Map Delegates"
    }

    static func exampleDetail() -> String {
        return """
        Map that logs delegate callbacks.
        
        • All MRMapViewDelegate methods are logged to console.
        """
    }

    // MARK: - MRMapViewDelegate

    override func mapPickerDidPick(_ map: MRMap) {
        super.mapPickerDidPick(map)
        print(#function)
    }

    override func mapViewWillStartLoadingMap(_ mapView: MRMapView) {
        super.mapViewWillStartLoadingMap(mapView)
        print(#function)
    }

    override func mapViewDidFinishLoadingMap(_ mapView: MRMapView) {
        super.mapViewDidFinishLoadingMap(mapView)
        print(#function)
    }

    override func mapViewDidFailLoadingMap(_ mapView: MRMapView, withError error: Error?) {
        super.mapViewDidFailLoadingMap(mapView, withError: error)
        print(#function + " - error: \(error?.localizedDescription ?? "None")")
    }

    override func mapViewDidChangeUseAccessiblePaths(_ mapView: MRMapView) {
        super.mapViewDidChangeUseAccessiblePaths(mapView)
        print(#function)
    }

    override func mapView(_ mapView: MRMapView, routeDidChange route: MRRoute) {
        super.mapView(mapView, routeDidChange: route)
        print(#function)
    }

    override func mapView(_ mapView: MRMapView, willScrollToStepAt index: UInt) {
        super.mapView(mapView, willScrollToStepAt: index)
        print(#function + " - index: \(index)")
    }

    override func mapView(_ mapView: MRMapView, willScrollTo rect: CGRect, for step: MRRouteStep) -> CGRect {
        let rect = super.mapView(mapView, willScrollTo: rect, for: step)
        print(#function + " - rect: \(rect)")
        return rect
    }

    override func mapView(_ mapView: MRMapView, visibleMapRectDidChange animated: Bool) {
        super.mapView(mapView, visibleMapRectDidChange: animated)
        print(#function + " - animated: \(animated)")
    }

    override func mapView(_ mapView: MRMapView, viewFor annotation: MRAnnotation?) -> MRAnnotationView? {
        let view = super.mapView(mapView, viewFor: annotation)
        print(#function + " - annotation: \(annotation?.description ?? "None")")
        return view
    }

    override func mapView(_ mapView: MRMapView, didAdd views: [MRAnnotationView]) {
        super.mapView(mapView, didAdd: views)
        print(#function + " - views: \(views.count)")
    }

    override func mapView(_ mapView: MRMapView, rendererFor overlay: MRPathOverlay) -> MRPathRenderer? {
        let renderer = super.mapView(mapView, rendererFor: overlay)
        print(#function)
        return renderer
    }

    override func mapView(_ mapView: MRMapView, didAddOverlayRenderers renderers: [MRPathRenderer]) {
        super.mapView(mapView, didAddOverlayRenderers: renderers)
        print(#function + " - renderers: \(renderers.count)")
    }

    override func mapView(_ mapView: MRMapView, didLoad placemarks: [MRPlacemark]) {
        super.mapView(mapView, didLoad: placemarks)
        print(#function + " - placemarks: \(placemarks.count)")
    }

    override func mapView(_ mapView: MRMapView, didLoad tags: [MRTag]) {
        super.mapView(mapView, didLoad: tags)
        print(#function + " - tags: \(tags.count)")
    }

    override func mapView(_ mapView: MRMapView, didUpdate tag: MRTag) {
        super.mapView(mapView, didUpdate: tag)
        print(#function + " - tag: \(tag.mac)")
    }

    override func mapView(_ mapView: MRMapView, willSelect view: MRAnnotationView) -> MRAnnotationView? {
        let annotationView = super.mapView(mapView, willSelect: view)
        print(#function + " - view: \(view.annotation.description)")
        return annotationView
    }

    override func mapView(_ mapView: MRMapView, didSelect view: MRAnnotationView) {
        super.mapView(mapView, didSelect: view)
        print(#function + " - view: \(view.description)")
    }

    override func mapView(_ mapView: MRMapView, didDeselect views: [MRAnnotationView]) {
        super.mapView(mapView, didDeselect: views)
        print(#function + " - views: \(views.count)")
    }

    override func mapView(_ mapView: MRMapView, willTap overlay: MRPathOverlay) -> MRPathOverlay {
        let overlay = super.mapView(mapView, willTap: overlay)
        print(#function)
        return overlay
    }

    override func mapView(_ mapView: MRMapView, didTap overlay: MRPathOverlay) {
        super.mapView(mapView, didTap: overlay)
        print(#function)
    }

    override func viewController(for mapView: MRMapView, selectedAnnotationView view: MRAnnotationView) -> MRDBottomSheetAbstractController? {
        let controller = super.viewController(for: mapView, selectedAnnotationView: view)
        print(#function + " - view: \(view.annotation.description)")
        return controller
    }

    override func mapView(_ mapView: MRMapView, locationProviderDidChangeFrom previousProviderType: MRLocationProviderType, to newProviderType: MRLocationProviderType) {
        super.mapView(mapView, locationProviderDidChangeFrom: previousProviderType, to: newProviderType)
        print(#function + " from: \(previousProviderType) to: \(newProviderType)")
    }

    override func mapView(_ mapView: MRMapView, didRequestMapPickerForMapKey key: MREditorKey) {
        super.mapView(mapView, didRequestMapPickerForMapKey: key)
        print(#function + " key: \(key.identifier)")
    }

    override func mapView(_ mapView: MRMapView, didLoad friends: [MRFriend]) {
        super.mapView(mapView, didLoad: friends)
        print(#function + " friends: \(friends.count)")
    }

    override func mapPickerDetailString(for map: MRMap) -> String? {
        let detail = super.mapPickerDetailString(for: map)
        print(#function + " map: \(map.key.identifier)")
        return detail
    }

    override func shouldRespondToUserLocationButton() -> Bool {
        let shouldRespond = super.shouldRespondToUserLocationButton()
        print(#function)
        return shouldRespond
    }

    override func mapView(_ mapView: MRMapView, requestedDirectionsTo placemark: MRPlacemark) {
        super.mapView(mapView, requestedDirectionsTo: placemark)
        print(#function + " placemark: \(placemark.key.identifier)")
    }
}
