//
//  MSShowsButtonsViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/19/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSShowsButtonsViewController: MRMapViewController, MSExampleViewController {
    convenience init() {
        self.init(nibName:nil, bundle:nil)
        mapView.mapKey = MREditorKey(forMap: MSExampleHost.mapID(), app: MSExampleHost.appID())
        mapView.showsUserLocation = true
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()

        let button0 = UIBarButtonItem(title: "Map", style: .plain, target: self, action: #selector(toggleLevels))
        let button1 = UIBarButtonItem(title: "Over.", style: .plain, target: self, action: #selector(toggleOverview))
        let button2 = UIBarButtonItem(title: "Loc.", style: .plain, target: self, action: #selector(toggleLocation))
        let button3 = UIBarButtonItem(title: "Acc.", style: .plain, target: self, action: #selector(toggleAccessibility))
        navigationItem.rightBarButtonItems = [button0, button1, button2, button3]
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Button Visibility"
    }

    static func exampleDetail() -> String {
        return """
        Example of how to show/hide map buttons.
        
        • `Acc.` button to toggle accessibility button visibility (during directions only).
        • `Loc.` button to toggle location button visibility.
        • `Over.` button to toggle overview button visibility.
        • `Map` button to toggle map picker visibility.
        """
    }

    // MARK: - Action

    @objc private func toggleLevels() {
        mapView.showsMapPicker = !mapView.showsMapPicker
    }

    @objc private func toggleOverview() {
        mapView.showsOverviewButton = !mapView.showsOverviewButton
    }

    @objc private func toggleLocation() {
        mapView.showsLocationButton = !mapView.showsLocationButton
    }

    @objc private func toggleAccessibility() {
        mapView.showsAccessibilityButton = !mapView.showsAccessibilityButton
    }
}
