//
//  MSVisibleMapRectViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/19/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSVisibleMapRectViewController: MRMapViewController, MSExampleViewController {
    convenience init() {
        self.init(nibName:nil, bundle:nil)
        mapView.mapKey = MREditorKey(forMap: MSExampleHost.mapID(), app: MSExampleHost.appID())
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()

        let button0 = UIBarButtonItem(title: "Zoom", style: .plain, target: self, action: #selector(zoomAction))
        let button1 = UIBarButtonItem(title: "Overview", style: .plain, target: self, action: #selector(overviewAction))
        navigationItem.rightBarButtonItems = [button0, button1]
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Zoom and Rotation"
    }

    static func exampleDetail() -> String {
        return """
        Example of how to programatically change the visible map rect.
        
        • Map starts zoomed to the upper left corner.
        • Button to show the full map.
        • Button to zoom onto the 'Widu' placemark.
        """
    }

    // MARK: - MRMapViewDelegate

    override func mapViewDidFinishLoadingMap(_ mapView: MRMapView) {
        super.mapViewDidFinishLoadingMap(mapView)
        mapView.setVisibleMapRect(CGRect(x: 100, y: 100, width: 100, height: 100), animated: false, completion: nil)
    }

    // MARK: - Action

    @objc private func zoomAction() {
        for i in mapView.placemarks {
            if let placemarkTitle = i.title, placemarkTitle == "Widu" {
                let width: CGFloat = 15 * mapView.map.unitsPerMeter
                let visibleRect = CGRect(x: i.point.x - width/2, y: i.point.y - width/2, width: width, height: width)
                mapView.setVisibleMapRect(visibleRect, rotationAngle: CGFloat(Double.pi/4), animated: true, completion: nil)
            }
        }
    }

    @objc private func overviewAction() {
        let map = mapView.map
        mapView.setVisibleMapRect(CGRect(x: 0, y: 0, width: map.size.width, height: map.size.height), animated: true, completion: nil)
    }
}
